@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.0901';
+our $VERSION = '0.0902';
 
 use Moo;
 use MIDI::Simple;
@@ -97,6 +97,7 @@ sub metronome44 { shift->metronome(@_) }
 sub metronome {
     my $self = shift;
     my $bars = shift || $self->bars;
+    my $flag = shift || 0;
 
     my $i = 0;
 
@@ -106,14 +107,21 @@ sub metronome {
             $self->note( $self->quarter, $self->open_hh, $self->snare );
         }
         else {
-            if ( $i % 2 == 0 )
+            if ( $flag == 0 )
             {
                 $self->note( $self->quarter, $self->open_hh, $self->kick );
             }
             else
             {
-                $self->note( $self->eighth, $self->open_hh, $self->kick );
-                $self->note( $self->eighth, $self->kick );
+                if ( $i % 2 == 0 )
+                {
+                    $self->note( $self->quarter, $self->open_hh, $self->kick );
+                }
+                else
+                {
+                    $self->note( $self->eighth, $self->open_hh, $self->kick );
+                    $self->note( $self->eighth, $self->kick );
+                }
             }
 
             $i++;
@@ -153,7 +161,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.0901
+version 0.0902
 
 =head1 SYNOPSIS
 
@@ -333,9 +341,15 @@ If no bars are given, the default times the number of beats is used.
 
   $d->metronome44;
   $d->metronome44($bars);
+  $d->metronome44($bars, $flag);
+  $d->metronome44(16, 1);
+  $d->metronome44(0, 1); # Use the ->bars attribute
 
 Add a steady 4/4 beat to the score.
 
+If a B<flag> is provided the beat is modified to include alternating
+eighth-note kicks.
+
 =head2 metronome34
 
   $d->metronome34;
@@ -350,6 +364,8 @@ constuctor.
 
 =head1 SEE ALSO
 
+The F<t/*> and F<eg/*> programs in this distribution
+
 L<Moo>
 
 L<MIDI::Simple>
